@@ -1,11 +1,11 @@
 
-from requests.api import request
 from requests.sessions import session
+from securityscorecard_api.compliance import Compliance
+from securityscorecard_api.events import Events
 from securityscorecard_api.scores import Scores
-from securityscorecard_api._util import _Util
 
 
-class SecurityScorecardClient(Scores, _Util):
+class SecurityScorecardClient(Scores, Events, Compliance):
     '''
         Primary Client Class 
     '''
@@ -14,4 +14,8 @@ class SecurityScorecardClient(Scores, _Util):
         self.session.headers = {
             "Accept": "application/json; charset=utf-8",
             "Authorization": "Token "+ api_token
-        }
\ No newline at end of file
+        }
+
+    def _perform_get(self, api_url):
+        response = self.session.get(api_url, verify=False)
+        return (response.json())
